local ADDON_NAME = "GearGrinder";

local L = LibStub("AceLocale-3.0"):GetLocale(ADDON_NAME, true);

local RAID_DUNGEONIDS = {
				MV = 531,
				HoF = 533,
				ToES = 535,
				ToT = 633,
				SoO = 714,
			};

local VALOR_CURRENCY_ID = 396
local JUSTICE_CURRENCY_ID = 395
local HONOR_CURRENCY_ID = 392
local CONQUEST_CURRENCY_ID = 390
local ELDER_CHARM_CURRENCY_ID = 697
local LESSER_CHARM_CURRENCY_ID = 738
local MOGU_CHARM_CURRENCY_ID = 752
local TIMELESS_CHARM_CURRENCY_ID = 777
local WARSEAL_CHARM_CURRENCY_ID = 776


-- Options for AceOptions

GG_Options = {
	name = L.core.options.name,
	desc = L.core.desc,
	type = "group",
	args = {
		general = {
			name = L.core.options.options,
			type = "group",
			inline = true,
			order = 1,
			args = {
				x = { 
					name = "General options",
					type = "description",
					fontSize = "small",
					order = 1,
				},
				cinfoVP = { -- Paperdoll VP Information
					name = L.core.options.paperdollVP,
					desc = L.core.options.paperdollVPDesc,
					type = "toggle",
					set = function(i,v) GG:SetVPPaperdoll(v) end,
					get = function(i) return GG:GetVPPaperdoll() end,
					order = 21,
				},
				cinfoGG = { -- Paperdoll VP Cap Information
					name = L.core.options.paperdollVPCap,
					desc = L.core.options.paperdollVPCapDesc,
					type = "toggle",
					set = function(i,v) GG:SetVPCapPaperdoll(v) end,
					get = function(i) return GG:GetVPCapPaperdoll() end,
					order = 22,
				},
				cinfoJP = { -- Paperdoll JP Information
					name = L.core.options.paperdollJP,
					desc = L.core.options.paperdollJPDesc,
					type = "toggle",
					set = function(i,v) GG:SetJPPaperdoll(v) end,
					get = function(i) return GG:GetJPPaperdoll() end,
					order = 23,
				},
				combat = { -- Disable the tooltip if in combat
					name = L.core.options.combat,
					desc = L.core.options.combatDesc,
					type = "toggle",
					set = function(i,v) GG:SetShowCombat(v) end,
					get = function(i) return GG:GetShowCombat() end,
					order = 24,
				},
				minimap = { -- Minimap Button
					name = L.core.options.minimap,
					desc = L.core.options.minimapDesc,
					type = "toggle",
					set = function(i,v) GG:SetMinimap(v) end,
					get = function(i) return GG:GetMinimap() end,
					order = 25,
				},
				filtering = { -- enable/disable character filtering
					name = L.core.options.filtering,
					desc = L.core.options.filteringDesc,
					type = "toggle",
					set = function(i,v) GG:SetFiltering(v) end,
					get = function(i) return GG:GetFiltering() end,
					order = 26,
				},
				ttScale = { -- UI Scale of the tooltip
					name = L.core.options.scale,
					desc = L.core.options.scaleDesc,
					type = "range",
					max = 2,
					min = 0.5,
					step = 0.1,
					set = function(i,v) GG:SetTTScale(v) end,
					get = function(i) return GG:GetTTScale() end,
					order = 28,
				},
				sortOrder = { -- Sort Order
					name = L.core.options.sortOrder,
					desc = L.core.options.sortOrderDesc,
					type = "select",
					style = "dropdown",
					set = function(i,v) GG:SetSortOrder(v) end,
					get = function(i) return GG:GetSortOrder() end,
					values = { 	
						[1] = "Unsorted",
						[2] = "Alphabetical",
						[3] = "Class", 
						[5] = "iLevel",
						[4] = "Valor Points",
						[8] = "VP Cap Progress",
						[6] = "Justice Points",
						[7] = "Charms"},
					order = 29,
				},
				reset_dayofweek = { -- Reset Day of Week
					name = L.core.options.resetDayOfWeek,
					desc = L.core.options.resetDayOfWeekDesc,
					type = "select",
					style = "dropdown",
					set = function(i,v) GG:SetResetDayOfWeek(v) end,
					get = function(i) return GG:GetResetDayOfWeek() end,
					values = { 	
						[1] = "Monday",
						[2] = "Tuesday", 
						[3] = "Wednesday",
						[4] = "Thursday", 
						[5] = "Friday",
						[6] = "Saturday",
						[0] = "Sunday" },
					order = 30,
				},
				reset_hour = { -- Reset Hour of day
					name = L.core.options.resetHour,
					desc = L.core.options.resetHourDesc,
					type = "select",
					style = "dropdown",
					set = function(i,v) GG:SetResetHour(v) end,
					get = function(i) return GG:GetResetHour() end,
					values = { 	
						[0] = "12am",
						[1] = "1am",
						[2] = "2am",
						[3] = "3am",
						[4] = "4am",
						[5] = "5am",
						[6] = "6am",
						[7] = "7am",
						[8] = "8am",
						[9] = "9am",
						[10] = "10am",
						[11] = "11am",
						[12] = "12pm",
						[13] = "1pm",
						[14] = "2pm",
						[15] = "3pm",
						[16] = "4pm",
						[17] = "5pm",
						[18] = "6pm",
						[19] = "7pm",
						[20] = "8pm",
						[21] = "9pm",
						[22] = "10pm",
						[23] = "11pm"},
					order = 31,
				},
				daily_reset_hour = { -- Dailies Reset Hour of day
					name = L.core.options.dailyResetHour,
					desc = L.core.options.dailyResetHourDesc,
					type = "select",
					style = "dropdown",
					set = function(i,v) GG:SetDailyResetHour(v) end,
					get = function(i) return GG:GetDailyResetHour() end,
					values = { 	
						[0] = "12am",
						[1] = "1am",
						[2] = "2am",
						[3] = "3am",
						[4] = "4am",
						[5] = "5am",
						[6] = "6am",
						[7] = "7am",
						[8] = "8am",
						[9] = "9am",
						[10] = "10am",
						[11] = "11am",
						[12] = "12pm",
						[13] = "1pm",
						[14] = "2pm",
						[15] = "3pm",
						[16] = "4pm",
						[17] = "5pm",
						[18] = "6pm",
						[19] = "7pm",
						[20] = "8pm",
						[21] = "9pm",
						[22] = "10pm",
						[23] = "11pm"},
					order = 32,
				},				
				--[[instruction = { -- button to show the help screen
					name = L.core.options.instruction,
					desc = L.core.options.instructionDesc,
					type = "execute",
					confirm = false,
					func = function(i) return GG:ShowHelp() end,
					order = 20,
				},]]
				purge = {
					name = L.core.options.purge,
					desc = L.core.options.purgeDesc,
					type = "execute",
					func = function(i) GG:PurgeDB(false) end,
					confirm = true,
					order = 99,
				},
			},
		},

		ttToons = {
			name = "Character Settings",
			type = "group",
			inline = true,
			order = 4,
			cmdHidden = true,
			args = {
				desc4 = { 
					name = " ",
					type = "description",
					--fontSize = "large",
					order = 1,
				},
				desc = { 
					name = "|cff00FF00Configure which Columns are displayed|r",
					type = "description",
					fontSize = "large",
					order = 5,
				},
				tooniELevel = { -- Show iELevel
					name = L.core.options.TooniELevel,
					--desc = L.core.options.tooniLevelDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GG:SetTooniELevel(v) end,
					get = function(i) return GG:GetTooniELevel() end,
					order = 9,
				},
				tooniLevel = { -- Show iLevel
					name = L.core.options.TooniLevel,
					--desc = L.core.options.tooniLevelDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GG:SetTooniLevel(v) end,
					get = function(i) return GG:GetTooniLevel() end,
					order = 10,
				},
				toonVPCap = { -- Show Valor Point Cap
					name = L.core.options.ToonVPCap,
					--desc = L.core.options.iLevelDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GG:SetToonVPCap(v) end,
					get = function(i) return GG:GetToonVPCap() end,
					order = 11,
				},
				toonVP = { -- Show Valor Points
					name = GetCurrencyInfo(VALOR_CURRENCY_ID), --L.core.options.ToonVP,
					--desc = L.core.options.iLevelDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GG:SetToonVP(v) end,
					get = function(i) return GG:GetToonVP() end,
					order = 12,
				},
				toonJP = { -- Show Justice Points
					name = GetCurrencyInfo(JUSTICE_CURRENCY_ID), --L.core.options.ToonJP,
					--desc = L.core.options.iLevelDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GG:SetToonJP(v) end,
					get = function(i) return GG:GetToonJP() end,
					order = 13,
				},
				toonHP = { -- Show Honor Points
					name = GetCurrencyInfo(HONOR_CURRENCY_ID), --L.core.options.ToonHP,
					--desc = L.core.options.iLevelDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GG:SetToonHP(v) end,
					get = function(i) return GG:GetToonHP() end,
					order = 14,
				},
				toonCP = { -- Show Conquest Points
					name = GetCurrencyInfo(CONQUEST_CURRENCY_ID), --L.core.options.ToonCP,
					--desc = L.core.options.iLevelDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GG:SetToonCP(v) end,
					get = function(i) return GG:GetToonCP() end,
					order = 15,
				},
				toonTimeless = { -- Show Timeless Coins
					name = GetCurrencyInfo(TIMELESS_CHARM_CURRENCY_ID), --L.core.options.ToonTimeless,
					--desc = L.core.options.charmDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GG:SetToonTimeless(v) end,
					get = function(i) return GG:GetToonTimeless() end,
					order = 16,
				},
				toonCharm = { -- Show Charms
					name = L.core.options.ToonCharm,
					--desc = L.core.options.charmDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GG:SetToonCharms(v) end,
					get = function(i) return GG:GetToonCharms() end,
					order = 17,
				},
				toonActivity = { -- Show Daily/Weekly Activity indicators
					name = "Show " .. L.core.options.ToonActivity,
					--desc = L.core.options.activityDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GG:SetToonActivity(v) end,
					get = function(i) return GG:GetToonActivity() end,
					order = 18,
				},
				toonProfCD = { -- enable/disable profession cooldowns
					name = L.core.options.ToonProfCD,
					--desc = L.core.options.profCDDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GG:SetToonProfCD(v) end,
					get = function(i) return GG:GetToonProfCD() end,
					order = 19,
				},
				toonFarm = { -- enable/disable farming
					name = L.core.options.ToonFarm,
					--desc = L.core.options.farmDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GG:SetToonFarm(v) end,
					get = function(i) return GG:GetToonFarm() end,
					order = 20,
				},
				
			},
		},
		
		ttCharms = {
			name = "Charms",
			type = "group",
			inline = true,
			order = 4,
			cmdHidden = true,
			args = {
				desc4 = { 
					name = " ",
					type = "description",
					--fontSize = "large",
					order = 1,
				},
				desc = { 
					name = "|cff00FF00Configure which Bonus Roll Tokens are displayed|r",
					type = "description",
					fontSize = "large",
					order = 5,
				},
				charms = { -- Show Charms
					name = "Show " .. L.core.options.ToonCharm,
					--desc = L.core.options.charmDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GG:SetToonCharms(v) end,
					get = function(i) return GG:GetToonCharms() end,
					order = 6,
				},
				desc3 = { 
					name = " ",
					type = "description",
					fontSize = "medium",
					order = 12,
				},
				head = { 
					name = "Tier 14",
					type = "header",
					order = 13,
				},
				charmLesser = { -- 
					name = GetCurrencyInfo(LESSER_CHARM_CURRENCY_ID),
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetCharmLesser(v) end,
					get = function(i) return GG:GetCharmLesser() end,
					width = "full",
					order = 21,
				},	
				charmElder = { -- 
					name = GetCurrencyInfo(ELDER_CHARM_CURRENCY_ID),
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetCharmElder(v) end,
					get = function(i) return GG:GetCharmElder() end,
					width = "full",
					order = 22,
				},	
				head2 = { 
					name = "Tier 15",
					type = "header",
					order = 30,
				},
				charmMogu = { -- 
					name = GetCurrencyInfo(MOGU_CHARM_CURRENCY_ID),
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetCharmMogu(v) end,
					get = function(i) return GG:GetCharmMogu() end,
					width = "full",
					order = 31,
				},	
				head3 = { 
					name = "Tier 16",
					type = "header",
					order = 40,
				},
				
				charmWarSeal = { -- 
					name = GetCurrencyInfo(WARSEAL_CHARM_CURRENCY_ID),
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetCharmWarSeal(v) end,
					get = function(i) return GG:GetCharmWarSeal() end,
					width = "full",
					order = 42,
				},	
		
			},
		},
		
		ttActivities = {
			name = L.core.options.ttActivity,
			type = "group",
			inline = true,
			order = 3,
			cmdHidden = true,
			args = {
				desc4 = { 
					name = " ",
					type = "description",
					--fontSize = "large",
					order = 1,
				},
				desc = { 
					name = "|cff00FF00Configure the Daily/Weekly Activities|r",
					type = "description",
					fontSize = "large",
					order = 5,
				},
				
				activity = { -- Show Daily/Weekly Activity indicators
					name = "Show " .. L.core.options.ToonActivity,
					--desc = L.core.options.activityDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GG:SetToonActivity(v) end,
					get = function(i) return GG:GetToonActivity() end,
					order = 6,
				},
				desc3 = { 
					name = " ",
					type = "description",
					fontSize = "medium",
					order = 12,
				},
				head = { 
					name = "Daily Activities",
					type = "header",
					order = 13,
				},
				H = { -- Show Daily Heroic
					name = L.core.options.ActivityH,
					--desc = L.core.options.HDesc,
					type = "toggle",
					set = function(i,v) GG:SetActivityH(v) end,
					get = function(i) return GG:GetActivityH() end,
					width = "full",
					order = 21,
				},
				HS = { -- Show Daily Heroic Scenario
					name = L.core.options.ActivityHS,
					--desc = L.core.options.HSDesc,
					type = "toggle",
					set = function(i,v) GG:SetActivityHS(v) end,
					get = function(i) return GG:GetActivityHS() end,
					width = "full",
					order = 22,
				},
				S = { -- Show Daily Scenario
					name = L.core.options.ActivityS,
					--desc = L.core.options.SDesc,
					type = "toggle",
					set = function(i,v) GG:SetActivityS(v) end,
					get = function(i) return GG:GetActivityS() end,
					width = "full",
					order = 23,
				},
				C = { -- Show Daily Challenge Mode Quest
					name = L.core.options.ActivityC,
					--desc = L.core.options.CDesc,
					type = "toggle",
					set = function(i,v) GG:SetActivityC(v) end,
					get = function(i) return GG:GetActivityC() end,
					width = "full",
					order = 24,
				},
				PM = { -- Show Daily Path of the Mistwalker Quest
					name = L.core.options.ActivityPM,
					--desc = L.core.options.PMDesc,
					type = "toggle",
					set = function(i,v) GG:SetActivityPM(v) end,
					get = function(i) return GG:GetActivityPM() end,
					width = "full",
					order = 25,
				},
				Tom = { -- Show Tomb "Tom" Bone Apart Chest Run
					name = L.core.options.ActivityTom,
					--desc = L.core.options.PMDesc,
					type = "toggle",
					set = function(i,v) GG:SetActivityTom(v) end,
					get = function(i) return GG:GetActivityTom() end,
					width = "full",
					order = 26,
				},
				desc2 = { 
					name = " ",
					type = "description",
					fontSize = "large",
					order = 31,
				},
				head2 = { 
					name = "Weekly Activities",
					type = "header",
					order = 32,
				},

				CoTK = { -- Show Weekly Champion of the Thunder King Quest
					name = L.core.options.ActivityCoTK,
					--desc = L.core.options.CoTKDesc,
					type = "toggle",
					set = function(i,v) GG:SetActivityCoTK(v) end,
					get = function(i) return GG:GetActivityCoTK() end,
					width = "full",
					order = 41,
				},
				EH = { -- Show Weekly Empowering the Hourglass Quest
					name = L.core.options.ActivityEH,
					--desc = L.core.options.EHDesc,
					type = "toggle",
					set = function(i,v) GG:SetActivityEH(v) end,
					get = function(i) return GG:GetActivityEH() end,
					width = "full",
					order = 43,
				},
			},
		},

		ttProfs = {
			name = L.core.options.ttProfs,
			type = "group",
			inline = true,
			order = 4,
			cmdHidden = true,
			args = {
				desc4 = { 
					name = " ",
					type = "description",
					--fontSize = "large",
					order = 1,
				},
				desc = { 
					name = "|cff00FF00Configure which Profession Cooldowns are displayed|r",
					type = "description",
					fontSize = "large",
					order = 5,
				},
				profCD = { -- enable/disable profession cooldowns
					name = "Show " .. L.core.options.ToonProfCD,
					--desc = L.core.options.profCDDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GG:SetToonProfCD(v) end,
					get = function(i) return GG:GetToonProfCD() end,
					order = 11,
				},
				desc3 = { 
					name = " ",
					type = "description",
					fontSize = "medium",
					order = 12,
				},
				head = { 
					name = "Profession Cooldown Selections",
					type = "header",
					order = 13,
				},
				ProfAlc = { -- Alchemy [Transmute: Living Steel]
					name = L.core.options.ProfAlc,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetProfAlc(v) end,
					get = function(i) return GG:GetProfAlc() end,
					width = "full",
					order = 21,
				},
				ProfBS = { -- Blacksmith  [Lightning Steel Ingot]
					name = L.core.options.ProfBS,
					--desc = L.core.options.ProfBSDesc,
					type = "toggle",
					set = function(i,v) GG:SetProfBS(v) end,
					get = function(i) return GG:GetProfBS() end,
					width = "full",
					order = 22,
				},
				ProfBS2 = { -- Blacksmith  [Balanced Trillium Ingot]
					name = L.core.options.ProfBS2,
					--desc = L.core.options.ProfBSDesc,
					type = "toggle",
					set = function(i,v) GG:SetProfBS2(v) end,
					get = function(i) return GG:GetProfBS2() end,
					width = "full",
					order = 23,
				},
				ProfEnch = { -- Enchanting  [Sha Crystal]
					name = L.core.options.ProfEnch,
					--desc = L.core.options.ProfEnchDesc,
					type = "toggle",
					set = function(i,v) GG:SetProfEnch(v) end,
					get = function(i) return GG:GetProfEnch() end,
					width = "full",
					order = 24,
				},
				ProfEng = { -- Engineering [Jard's Peculiar Energy Source]
					name = L.core.options.ProfEng,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GG:SetProfEng(v) end,
					get = function(i) return GG:GetProfEng() end,
					width = "full",
					order = 25,
				},
				ProfScribe = { -- Inscription [Scroll of Wisdom]
					name = L.core.options.ProfScribe,
					--desc = L.core.options.ProfScribeDesc,
					type = "toggle",
					set = function(i,v) GG:SetProfScribe(v) end,
					get = function(i) return GG:GetProfScribe() end,
					width = "full",
					order = 26,
				},
				ProfJCGem = { -- Jewelcrafting [Facets of Research]
					name = L.core.options.ProfJCGem,
					--desc = L.core.options.ProfJCGemDesc,
					type = "toggle",
					set = function(i,v) GG:SetProfJCGem(v) end,
					get = function(i) return GG:GetProfJCGem() end,
					width = "full",
					order = 27,
				},
				ProfJCHeart = { -- Jewelcrafting [Serpent's Heart]
					name = L.core.options.ProfJCHeart,
					--desc = L.core.options.ProfJCHeartDesc,
					type = "toggle",
					set = function(i,v) GG:SetProfJCHeart(v) end,
					get = function(i) return GG:GetProfJCHeart() end,
					width = "full",
					order = 28,
				},
				ProfLW = { -- Leatherworking [Magnificence of Leather]
					name = L.core.options.ProfLW,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GG:SetProfLW(v) end,
					get = function(i) return GG:GetProfLW() end,
					width = "full",
					order = 29,
				},
				ProfLW2 = { -- Leatherworking [Hardened Magnificant Hide]
					name = L.core.options.ProfLW2,
					--desc = L.core.options.ProfLWDesc,
					type = "toggle",
					set = function(i,v) GG:SetProfLW2(v) end,
					get = function(i) return GG:GetProfLW2() end,
					width = "full",
					order = 30,
				},
				ProfTailor = { -- Tailoring  [Imperial Silk]
					name = L.core.options.ProfTailor,
					--desc = L.core.options.ProfTailorDesc,
					type = "toggle",
					set = function(i,v) GG:SetProfTailor(v) end,
					get = function(i) return GG:GetProfTailor() end,
					width = "full",
					order = 31,
				},
				ProfTailor2 = { -- Tailoring  [Celestial Cloth]
					name = L.core.options.ProfTailor2,
					--desc = L.core.options.ProfTailorDesc,
					type = "toggle",
					set = function(i,v) GG:SetProfTailor2(v) end,
					get = function(i) return GG:GetProfTailor2() end,
					width = "full",
					order = 32,
				},
			},
		},

		ttRaids = {
			name = L.core.options.ttRaids,
			type = "group",
			inline = true,
			order = 5,
			cmdHidden = true,
			args = {
				desc4 = { 
					name = " ",
					type = "description",
					--fontSize = "large",
					order = 1,
				},
				desc = { 
					name = "|cff00FF00Configure which Raids are displayed|r",
					type = "description",
					fontSize = "large",
					order = 5,
				},
				lfr = { -- Show the LFR section the tooltip
					name = L.core.options.LFR,
					desc = L.core.options.LFRDesc,
					type = "toggle",
					width = "full",
					set = function(i,v) GG:SetLFR(v) end,
					get = function(i) return GG:GetLFR() end,
					order = 8,
				},
				lfrNormal = {  -- Show the non-LFR saves in the Raid section
					name = L.core.options.LFRNormal,
					desc = L.core.options.LFRNormalDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GG:SetLFRNormal(v) end,
					get = function(i) return GG:GetLFRNormal() end,
					order = 9,
				},
				lfrFlex = {  -- Show the non-LFR saves in the Raid section
					name = L.core.options.LFRFlex,
					desc = L.core.options.LFRFlexDesc,
					width = "full",
					type = "toggle",
					set = function(i,v) GG:SetLFRFlex(v) end,
					get = function(i) return GG:GetLFRFlex() end,
					hidden = true,
					order = 10,
				},
				desc3 = { 
					name = " ",
					type = "description",
					fontSize = "medium",
					order = 12,
				},
				head = { 
					name = "Tier 14",
					type = "header",
					order = 13,
				},
				RaidMV = { -- 
					name = GetDungeonInfo(RAID_DUNGEONIDS["MV"]), --L.core.options.RaidMV,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetRaidMV(v) end,
					get = function(i) return GG:GetRaidMV() end,
					width = "full",
					order = 21,
				},	
				RaidHoF = { -- 
					name = GetDungeonInfo(RAID_DUNGEONIDS["HoF"]), --L.core.options.RaidHoF,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetRaidHoF(v) end,
					get = function(i) return GG:GetRaidHoF() end,
					width = "full",
					order = 22,
				},	
				RaidToES = { -- 
					name = GetDungeonInfo(RAID_DUNGEONIDS["ToES"]), --L.core.options.RaidMV,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetRaidToES(v) end,
					get = function(i) return GG:GetRaidToES() end,
					width = "full",
					order = 23,
				},	
				head2 = { 
					name = "Tier 15",
					type = "header",
					order = 30,
				},
				RaidToT = { -- 
					name = GetDungeonInfo(RAID_DUNGEONIDS["ToT"]), --L.core.options.RaidMV,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetRaidToT(v) end,
					get = function(i) return GG:GetRaidToT() end,
					width = "full",
					order = 31,
				},	
				head3 = { 
					name = "Tier 16",
					type = "header",
					order = 40,
				},
				RaidSoO = { -- 
					name = GetDungeonInfo(RAID_DUNGEONIDS["SoO"]), --L.core.options.RaidMV,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetRaidSoO(v) end,
					get = function(i) return GG:GetRaidSoO() end,
					width = "full",
					order = 41,
				},	
			},
		},

		ttBoss = {
			name = L.core.options.ttBoss,
			type = "group",
			inline = true,
			order = 6,
			cmdHidden = true,
			args = {
				desc4 = { 
					name = " ",
					type = "description",
					--fontSize = "large",
					order = 1,
				},
				desc = { 
					name = "|cff00FF00Configure which World Bosses are displayed|r",
					type = "description",
					fontSize = "large",
					order = 5,
				},
				worldBoss = { -- Show World Boss Status
					name = L.core.options.boss,
					desc = L.core.options.bossDesc,
					type = "toggle",
					set = function(i,v) GG:SetWorldBoss(v) end,
					get = function(i) return GG:GetWorldBoss() end,
					order = 6,
				},
				desc3 = { 
					name = " ",
					type = "description",
					fontSize = "medium",
					order = 12,
				},
				head = { 
					name = "Tier 14",
					type = "header",
					order = 13,
				},
				BossSha = { -- 
					name = L.core.BossShaOfAnger,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetBossSha(v) end,
					get = function(i) return GG:GetBossSha() end,
					width = "full",
					order = 21,
				},	
				BossGalleon = { -- 
					name = L.core.BossGalleon,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetBossGalleon(v) end,
					get = function(i) return GG:GetBossGalleon() end,
					width = "full",
					order = 22,
				},	
				head2 = { 
					name = "Tier 15",
					type = "header",
					order = 30,
				},
				BossNalak = { -- 
					name = L.core.BossNalak,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetBossNalak(v) end,
					get = function(i) return GG:GetBossNalak() end,
					width = "full",
					order = 31,
				},	
				BossOondasta = { -- 
					name = L.core.BossOondasta,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetBossOondasta(v) end,
					get = function(i) return GG:GetBossOondasta() end,
					width = "full",
					order = 32,
				},	
				head3 = { 
					name = "Tier 16",
					type = "header",
					order = 40,
				},
				BossCelestial = { -- 
					name = L.core.BossCelestial,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetBossCelestial(v) end,
					get = function(i) return GG:GetBossCelestial() end,
					width = "full",
					order = 41,
				},	
				BossOrdos = { -- 
					name = L.core.BossOrdos,
					--desc = L.core.options.ProfAlcDesc,
					type = "toggle",
					set = function(i,v) GG:SetBossOrdos(v) end,
					get = function(i) return GG:GetBossOrdos() end,
					width = "full",
					order = 42,
				},	
			},
		},
		
		ldbOpt = {
			name = L.core.options.ldb,
			type = "group",
			inline = true,
			order = 7,
			cmdHidden = true,
			args = {
				ldbText = {  -- Toggle the LDB Text competely
					name = L.core.options.ldbText,
					desc = L.core.options.ldbTextDesc,
					type = "toggle",
					get = function(i) return GG:GetLDB() end,
					set = function(i,v) GG:SetLDB(v) end,
					order = 1,
				},
				ldbLabel = { -- Toggle the characters name
					name = L.core.options.ldbSource,
					desc = L.core.options.ldbSourceDesc,
					type = "toggle",
					get = function(i) return GG:GetLDBlabel() end,
					set = function(i,v) GG:SetLDBlabel(v) end,
					order = 2,
				},
				ldbTextColor = { -- Toggle the Colorizing of the LDB Text
					name = L.core.options.ldbTextColor,
					desc = L.core.options.ldbTextColorDesc,
					type = "toggle",
					set = function(i,v) GG:SetLDBTextColor(v) end,
					get = function(i) return GG:GetLDBTextColor() end,
					order = 3,
				},
				ldbDisplay = { -- Selection of what to display on the LDB Button
					name = L.core.options.ldbDisplay,
					desc = L.core.options.ldbDisplayDesc,
					type = "select",
					style = "dropdown",
					set = function(i,v) GG:SetLDBDisplay(v) end,
					get = function(i) return GG:GetLDBDisplay() end,
					values = { 	
						[1] = "VP Cap (VP) <JP> [LFR]",
						[2] = "VP Cap (VP) [LFR]",
						[3] = "VP Cap (VP) <JP>",
						[4] = "VP Cap (VP)",
						[5] = "VP Cap [LFR]", 
						[6] = "VP Cap",
						[7] = "VP <JP> [LFR]",
						[8] = "VP <JP>",
						[9] = "VP [LFR]",
						[10] = "LFR",
					},
					order = 4,
				},
				ldbDisplayLock = { -- Toggle the locking of the LDB Text button
					name = L.core.options.ldbDisplayLock,
					desc = L.core.options.ldbDisplayLockDesc,
					type = "toggle",
					set = function(i,v) GG:SetLDBDisplayLock(v) end,
					get = function(i) return GG:GetLDBDisplayLock() end,
					order = 5,
				},
			},
		},
        
		Background = {
			type = "group",
			name = "Background Options",
			guiInline = true,
			order = 8,
			get = function(i) return GG:GetBGGeneric(i) end,
			set = function(i, v) GG:SetBGGeneric(i, v) end,
			args = {
				Texture = {
					type = "select", dialogControl = 'LSM30_Background',
					order = 1,
					name = "Background Texture",
					desc = "Texture to use for the frame's background",
					values = AceGUIWidgetLSMlists.background,
				},
				BorderTexture = {
					type = "select", dialogControl = 'LSM30_Border',
					order = 2,
					name = "Border Texture",
					desc = "Texture to use for the tooltip's border",
					values = AceGUIWidgetLSMlists.border,
				},
				Color = {
					type = "color",
					order = 3,
					name = "Background Color",
					desc = "Tooltip's background color",
					hasAlpha = true,
					get = function(i) return GG:GetBGColor() end,
					set = function(i, r, g, b, a) GG:SetBGColor(r, g, b, a) end,
				},
				BorderColor = {
					type = "color",
					order = 4,
					name = "Border Color",
					desc = "Tooltip's border color",
					hasAlpha = true,
					get = function(i) return GG:GetBGBorderColor() end,
					set = function(i, r, g, b, a) GG:SetBGBorderColor(r, g, b, a)	end,
				},
				Tile = {
					type = "toggle",
					order = 5,
					name = "Tile Background",
					desc = "Tile the background texture",
				},
				TileSize = {
					type = "range",
					order = 6,
					name = "Background Tile Size",
					desc = "The size used to tile the background texture",
					min = 16, max = 256, step = 1,
					disabled = function() return not GG:GetBGTile() end,
				},
				EdgeSize = {
					type = "range",
					order = 7,
					name = "Border Thickness",
					desc = "The thickness of the border",
					min = 1, max = 16, step = 1,
				},
			},
		},		
		
		-- Console Only
		options = {
			name = L.core.options.name,
			desc = L.core.options.optionDesc,
			type = "input",
			set = function(i) GG:ShowOptions() end,
			hidden = true,
			order = 49,
			guiHidden = true,
			cmdHidden = false,
		},
		--[[debug = { -- Debug mode
			name = 'Debug Mode',
			type = "toggle",
			set = function(i,v) GG:SetDebug(v) end,
			get = function() return GG:GetDebug() end,
			order = 50,
			hidden = true,
			guiHidden = true,
			cmdHidden = false,
		},]]
	},
};

GG_Defaults = {
	global = {
		daily_reset_hour = 2,	-- Hour the dailies are reset ie. 2AM
		reset_hour = 3,			-- Hour the VP Cap is reset ie. 3AM
		reset_dayofweek = 2,	-- Day of week when VP Cap is reset ie. Tuesday
		cinfoVP = true,
		cinfoVPCap = true,
		cinfoJP = true,
		combat = false,			-- don't show in combat
		filtering = true,		-- allow characater filtering.
		ttScale = 1,
		progress_orange = 100,
		progress_yellow = 200,
		JPStandardMax = 4000,
		VPStandardMax = 3000,
		VPStandardCapMax = 1000,
		HPStandardMax = 4000,
		minimap = {
			hide = false,		-- Minimap Icon
		},
		sortOrder = 5,			-- sort order of iLevel
		version = 1,			-- Version for future referance
		worldBoss = true,		-- Show World Boss status
		show_Icons = false,		-- Show the Icons on the tooltip
		
		-- Raid Settings
		lfr = true,				-- Show the LFR values on the tooltip
		lfrNormal = true,			-- Show the Non-LFR save details on the tooltip
		lfrFlex = true,
		
		-- LDB settings
		ldbTextColor = true,	-- LDB Text Colorize?
		ldbText = true,			-- LDB Text
		ldbLabel = false,		-- LDB Label
		ldbDisplay = 1,			-- LDB Text display 
		ldbDisplayLock = false, -- LDB button text display lock
		
		-- Toon indicators
		TooniLevel = true,			-- show iLevel
		TooniELevel = false,			-- show iELevel
		ToonActivity = true,		-- show the daily/weekly activity indicators
		ToonCharms = true,			-- show Charms
		ToonProfCD = true,			-- Show the profession cooldowns
		ToonFarm = true,			-- Show the Farm details
		ToonVPCap = true,
		ToonTimeless = true,
		ToonVP = true,
		ToonJP = true,
		ToonHP = false,
		ToonCP = false,
		
		-- Charm Indicators
		charmLesser = true,
		charmElder = true,
		charmMogu = true,
		charmWarSeal = true,
		
		-- Raid Indicators
		RaidMV = true,
		RaidHoF = true,
		RaidToES = true,
		RaidToT = true,
		RaidSoO = true,
		
		-- World Boss Indicators
		BossSha = true,
		BossGalleon = true,
		BossNalak = true,
		BossOondasta = true,
		BossCelestial = true,
		BossOrdos = true,
		
		-- Activity Indicators
		ActivityH = true,
		ActivityHS = true,
		ActivityS = false,
		ActivityC = false,
		ActivityCoTK = true,
		ActivityTom = true,
		ActivityEH = true,
		ActivityPM = true,

		-- Profession Cooldown Indicators
		ProfAlc = true,
		ProfBS = true,
		ProfBS2 = true,
		ProfTailor = true,
		ProfTailor2 = true,
		ProfEnch = true,
		ProfScribe = true,
		ProfJCGem = true,
		ProfJCHeart = true,
		ProfLW = true,
		ProfLW2 = true,
		ProfEng = true,
		
		Background = {
			Texture = "Blizzard Rock",
			BorderTexture = "Blizzard Tooltip",
			Color = {r = 0.5, g = 0.5, b = 0.5, a = 1,},
			BorderColor = {r = 0.95, g = 1, b = 1, a = 1,},
			Tile = false,
			TileSize = 32,
			EdgeSize = 10,
		},
	},
    char = {
        debug = false,          -- Debug mode
    }
};

